==> libxkbcommon-doc-1.11.0-1-x86_64.pkg.tar.zst: usr/share/doc/libxkbcommon/html/search/pages_d.js <==
var searchData=
[
  ['data_20locations_0',['Data locations',['../user-configuration.html#user-config-locations',1,'Data locations'],['../deprecated.html#_deprecated000001',1,'Data locations']]],
  ['dataset_1',['Dataset',['../index.html#dataset',1,'']]],
  ['debugging_2',['Debugging',['../debugging.html',1,'']]],
  ['declaration_20and_20binding_3',['Modifiers declaration and binding',['../keymap-text-format-v1-v2.html#modifiers-declaration-and-binding',1,'']]],
  ['declarations_4',['Modifiers declarations',['../keymap-text-format-v1-v2.html#virtual-modifier-statements',1,'']]],
  ['default_20field_5',['XKB-639 – Unknown default field',['../error-index.html#XKB-639',1,'']]],
  ['default_20section_6',['XKB-433 – Missing default section',['../error-index.html#XKB-433',1,'']]],
  ['default_20statement_7',['XKB-254 – Invalid set default statement',['../error-index.html#XKB-254',1,'']]],
  ['default_20values_8',['default values',['../keymap-text-format-v1-v2.html#set-default-values-1',1,'Set default values'],['../keymap-text-format-v1-v2.html#set-default-values-2',1,'Set default values']]],
  ['defaults_20wrong_20scope_9',['XKB-428 – Global defaults wrong scope',['../error-index.html#XKB-428',1,'']]],
  ['define_20and_20use_20a_20modifier_20step_20by_20step_10',['Example: define and use a modifier, step by step',['../keymap-text-format-v1-v2.html#example-define-and-use-a-modifier-step-by-step',1,'']]],
  ['defined_11',['Where are the keyboard layouts defined?',['../faq.html#where-are-the-keyboard-layouts-defined',1,'']]],
  ['definitions_12',['definitions',['../keymap-text-format-v1-v2.html#key-type-statement',1,'Type definitions'],['../error-index.html#XKB-407',1,'XKB-407 – Conflicting key type definitions']]],
  ['definitions_20examples_13',['Definitions examples',['../keymap-text-format-v1-v2.html#definitions-examples',1,'']]],
  ['deprecated_14',['Deprecated',['../release-notes.html#deprecated',1,'Deprecated'],['../release-notes.html#deprecated-1',1,'Deprecated']]],
  ['deprecated_20keysym_15',['XKB-301 – Deprecated keysym',['../error-index.html#XKB-301',1,'']]],
  ['deprecated_20keysym_20name_16',['XKB-302 – Deprecated keysym name',['../error-index.html#XKB-302',1,'']]],
  ['deprecated_20list_17',['Deprecated List',['../deprecated.html',1,'']]],
  ['details_18',['Details',['../error-index.html#details',1,'']]],
  ['development_19',['Development',['../index.html#development',1,'']]],
  ['device_20actions_20',['Device actions',['../keymap-text-format-v1-v2.html#device-actions',1,'Device actions'],['../todo.html#_todo000016',1,'Device actions'],['../todo.html#_todo000017',1,'Device actions'],['../todo.html#_todo000018',1,'Device actions']]],
  ['discoverable_20layouts_21',['Discoverable layouts',['../user-configuration.html#discoverable-layouts',1,'']]],
  ['do_20i_20break_20a_20latch_20before_20triggering_20another_20latch_20or_20lock_22',['How do I break a latch before triggering another latch or lock?',['../faq.html#how-do-i-break-a-latch-before-triggering-another-latch-or-lock',1,'']]],
  ['do_20i_20customize_20my_20layout_23',['How do I customize my layout?',['../faq.html#how-do-i-customize-my-layout',1,'']]],
  ['do_20i_20swap_20some_20keys_24',['How do I swap some keys?',['../faq.html#how-do-i-swap-some-keys',1,'']]],
  ['do_20i_20test_20my_20custom_20layout_20without_20installing_20it_25',['How do I test my custom layout without installing it?',['../faq.html#how-do-i-test-my-custom-layout-without-installing-it',1,'']]],
  ['do_20my_20keyboard_20shortcuts_20not_20work_20properly_26',['Why do my keyboard shortcuts not work properly?',['../faq.html#why-do-my-keyboard-shortcuts-not-work-properly',1,'']]],
  ['does_20…_20mean_27',['What does … mean?',['../faq.html#what-does--mean',1,'']]],
  ['does_20my_20key_20combination_20to_20switch_20between_20layouts_20not_20work_28',['Why does my key combination to switch between layouts not work?',['../faq.html#why-does-my-key-combination-to-switch-between-layouts-not-work',1,'']]],
  ['does_20my_20keyboard_20layout_20not_20work_20as_20expected_29',['Why does my keyboard layout not work as expected?',['../faq.html#why-does-my-keyboard-layout-not-work-as-expected',1,'']]],
  ['duplicate_20entry_30',['XKB-378 – Duplicate entry',['../error-index.html#XKB-378',1,'']]]
];

==> libxkbcommon-doc-1.12.0-2-x86_64.pkg.tar.zst: usr/share/doc/libxkbcommon/html/search/pages_d.js <==
var searchData=
[
  ['data_20locations_0',['Data locations',['../user-configuration.html#user-config-locations',1,'Data locations'],['../deprecated.html#_deprecated000001',1,'Data locations']]],
  ['dataset_1',['Dataset',['../index.html#dataset',1,'']]],
  ['debugging_2',['Debugging',['../debugging.html',1,'']]],
  ['declaration_20and_20binding_3',['Modifiers declaration and binding',['../keymap-text-format-v1-v2.html#modifiers-declaration-and-binding',1,'']]],
  ['declarations_4',['Modifiers declarations',['../keymap-text-format-v1-v2.html#virtual-modifier-statements',1,'']]],
  ['default_20field_5',['XKB-639 – Unknown default field',['../error-index.html#XKB-639',1,'']]],
  ['default_20section_6',['XKB-433 – Missing default section',['../error-index.html#XKB-433',1,'']]],
  ['default_20statement_7',['XKB-254 – Invalid set default statement',['../error-index.html#XKB-254',1,'']]],
  ['default_20values_8',['default values',['../keymap-text-format-v1-v2.html#set-default-values-1',1,'Set default values'],['../keymap-text-format-v1-v2.html#set-default-values-2',1,'Set default values']]],
  ['defaults_20wrong_20scope_9',['XKB-428 – Global defaults wrong scope',['../error-index.html#XKB-428',1,'']]],
  ['define_20and_20use_20a_20modifier_20step_20by_20step_10',['Example: define and use a modifier, step by step',['../keymap-text-format-v1-v2.html#example-define-and-use-a-modifier-step-by-step',1,'']]],
  ['defined_11',['Where are the keyboard layouts defined?',['../faq.html#where-are-the-keyboard-layouts-defined',1,'']]],
  ['definitions_12',['definitions',['../keymap-text-format-v1-v2.html#key-type-statement',1,'Type definitions'],['../error-index.html#XKB-407',1,'XKB-407 – Conflicting key type definitions']]],
  ['definitions_20examples_13',['Definitions examples',['../keymap-text-format-v1-v2.html#definitions-examples',1,'']]],
  ['deprecated_14',['Deprecated',['../release-notes.html#deprecated',1,'Deprecated'],['../release-notes.html#deprecated-1',1,'Deprecated'],['../release-notes.html#deprecated-2',1,'Deprecated']]],
  ['deprecated_20keysym_15',['XKB-301 – Deprecated keysym',['../error-index.html#XKB-301',1,'']]],
  ['deprecated_20keysym_20name_16',['XKB-302 – Deprecated keysym name',['../error-index.html#XKB-302',1,'']]],
  ['deprecated_20list_17',['Deprecated List',['../deprecated.html',1,'']]],
  ['details_18',['Details',['../error-index.html#details',1,'']]],
  ['development_19',['Development',['../index.html#development',1,'']]],
  ['device_20actions_20',['Device actions',['../keymap-text-format-v1-v2.html#device-actions',1,'Device actions'],['../todo.html#_todo000016',1,'Device actions'],['../todo.html#_todo000017',1,'Device actions'],['../todo.html#_todo000018',1,'Device actions']]],
  ['discoverable_20layouts_21',['Discoverable layouts',['../user-configuration.html#discoverable-layouts',1,'']]],
  ['do_20i_20break_20a_20latch_20before_20triggering_20another_20latch_20or_20lock_22',['How do I break a latch before triggering another latch or lock?',['../faq.html#how-do-i-break-a-latch-before-triggering-another-latch-or-lock',1,'']]],
  ['do_20i_20customize_20my_20layout_23',['How do I customize my layout?',['../faq.html#how-do-i-customize-my-layout',1,'']]],
  ['do_20i_20swap_20some_20keys_24',['How do I swap some keys?',['../faq.html#how-do-i-swap-some-keys',1,'']]],
  ['do_20i_20test_20my_20custom_20layout_20without_20installing_20it_25',['How do I test my custom layout without installing it?',['../faq.html#how-do-i-test-my-custom-layout-without-installing-it',1,'']]],
  ['do_20my_20keyboard_20shortcuts_20not_20work_20properly_26',['Why do my keyboard shortcuts not work properly?',['../faq.html#why-do-my-keyboard-shortcuts-not-work-properly',1,'']]],
  ['does_20…_20mean_27',['What does … mean?',['../faq.html#what-does--mean',1,'']]],
  ['does_20my_20key_20combination_20to_20switch_20between_20layouts_20not_20work_28',['Why does my key combination to switch between layouts not work?',['../faq.html#why-does-my-key-combination-to-switch-between-layouts-not-work',1,'']]],
  ['does_20my_20keyboard_20layout_20not_20work_20as_20expected_29',['Why does my keyboard layout not work as expected?',['../faq.html#why-does-my-keyboard-layout-not-work-as-expected',1,'']]],
  ['duplicate_20entry_30',['XKB-378 – Duplicate entry',['../error-index.html#XKB-378',1,'']]]
];
